@@ -1,11 +1,11 @@
 #include "abc_000_macro.h"
-#include "inttypes.h"
+#include "abc_000_warning.h"
 
 #if M_INTERFACE ==1
+	#include "inttypes.h"
 	#include "mex.h"
 	extern bool ioFlush(void);
-	extern "C"  void matlab_IOflush(void)
-	{
+	extern "C"  void matlab_IOflush(void)	{
 		ioFlush();
 	}
 
@@ -15,10 +15,10 @@
 	*/
 	 
 #else
-#include "abc_000_warning.h"
 static char achar UNUSED_DECORATOR ='c';
-#include "abc_000_warning.h"
 #endif
 
+#include "abc_000_warning.h"
+
 
 
